==> spip_3.2.9.orig.tar.xz: plugins-dist/revisions/lang/revisions_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'D’Ënnerscheeder weisen',

	// D
	'diff_para_ajoute' => 'Abschnitt bäigefléckt',
	'diff_para_deplace' => 'Abschnitt geréckelt',
	'diff_para_supprime' => 'Abschnitt geläscht',
	'diff_texte_ajoute' => 'Text bäigefléckt',
	'diff_texte_deplace' => 'Text geréckelt',
	'diff_texte_supprime' => 'Text geläscht',
	'differences_versions' => 'Differenz tëschent der Versioun Nr. @id_version@ an der Versioun Nr. @id_diff@',

	// I
	'icone_restaurer_version' => 'D’Versioun Nr. @version@ zeréckspillen',
	'icone_suivi_revisions' => 'Verwaltung vun de Versiounen',
	'info_1_revision' => '1 Versioun',
	'info_aucune_revision' => 'Kéng Versiounen',
	'info_historique' => 'Versiounen:',
	'info_historique_lien' => 'Geschicht vun de Versioune weisen',
	'info_historique_titre' => 'Versioning',
	'info_nb_revisions' => '@nb@ Versiounen',

	// L
	'label_choisir_id_version' => 'Wielt d’Versiounen déi solle verglach ginn',
	'label_config_revisions_objets' => 'D’Versiounen op dësen Objekter aschalten:',

	// M
	'message_valider_recuperer_version' => 'Bestätegt de Formulaire fir op dës Versioun zeréck ze fueren.',

	// O
	'objet_editorial' => 'Objet',

	// P
	'plugin_update' => 'Update vum Plugin "Révisions" op d’Versioun @version@.',

	// T
	'titre_form_revisions_objets' => 'Versiounen aschalten',
	'titre_restaurer_version' => 'Eng Versioun zeréckspillen',
	'titre_revisions' => 'Versiounen',

	// V
	'version_deplace_rubrique' => 'Geréckelt vun <b>"@from@"</b> op <b>"@to@"</b>.',
	'version_initiale' => 'Original-Versioun',
	'voir_differences' => 'D’Ënnerscheeder gesinn',
	'voir_mes_revisions' => 'Meng Versiounen',
	'voir_revisions' => 'D’Versioune gesinn (@objet@ @id_objet@: @titre@)',
	'voir_toutes_les_revisions' => 'All d’Versiounen'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'D’Ënnerscheeder weisen',

	// D
	'diff_para_ajoute' => 'Abschnitt bäigefléckt',
	'diff_para_deplace' => 'Abschnitt geréckelt',
	'diff_para_supprime' => 'Abschnitt geläscht',
	'diff_texte_ajoute' => 'Text bäigefléckt',
	'diff_texte_deplace' => 'Text geréckelt',
	'diff_texte_supprime' => 'Text geläscht',
	'differences_versions' => 'Differenz tëschent der Versioun Nr. @id_version@ an der Versioun Nr. @id_diff@',

	// I
	'icone_restaurer_version' => 'D’Versioun Nr. @version@ zeréckspillen',
	'icone_suivi_revisions' => 'Verwaltung vun de Versiounen',
	'info_1_revision' => '1 Versioun',
	'info_aucune_revision' => 'Kéng Versiounen',
	'info_historique' => 'Versiounen:',
	'info_historique_lien' => 'Geschicht vun de Versioune weisen',
	'info_historique_titre' => 'Versioning',
	'info_nb_revisions' => '@nb@ Versiounen',

	// L
	'label_choisir_id_version' => 'Wielt d’Versiounen déi solle verglach ginn',
	'label_config_revisions_objets' => 'D’Versiounen op dësen Objekter aschalten:',

	// M
	'message_valider_recuperer_version' => 'Bestätegt de Formulaire fir op dës Versioun zeréck ze fueren.',

	// O
	'objet_editorial' => 'Objet',

	// P
	'plugin_update' => 'Update vum Plugin "Révisions" op d’Versioun @version@.',

	// T
	'titre_form_revisions_objets' => 'Versiounen aschalten',
	'titre_restaurer_version' => 'Eng Versioun zeréckspillen',
	'titre_revisions' => 'Versiounen',

	// V
	'version_deplace_rubrique' => 'Geréckelt vun <b>"@from@"</b> op <b>"@to@"</b>.',
	'version_initiale' => 'Original-Versioun',
	'voir_differences' => 'D’Ënnerscheeder gesinn',
	'voir_mes_revisions' => 'Meng Versiounen',
	'voir_revisions' => 'D’Versioune gesinn (@objet@ @id_objet@: @titre@)',
	'voir_toutes_les_revisions' => 'All d’Versiounen',
];
